@@ -1,13 +1,14 @@
 
 package Text::Editor::Vip;
+
 use strict;
-use warnings ;
 
 BEGIN 
 {
 use Exporter ();
 use vars qw ($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-$VERSION     = '0.08';
+
+$VERSION     = 0.01_1;
 @ISA         = qw (Exporter);
 @EXPORT      = qw ();
 @EXPORT_OK   = qw ();
@@ -15,14 +16,26 @@ $VERSION     = '0.08';
 }
 
 
+
 =head1 NAME
 
-Text::Editor::Vip - Perl Editor
+Text::Editor::Vip - Text editor for Perl and other languages
+
+=head1 SYNOPSIS
+
+  use Text::Editor::Vip
+  
 
 =head1 DESCRIPTION
 
 See the README file.
 
+=head1 USAGE
+
+=head1 BUGS
+
+=head1 SUPPORT
+
 =head1 AUTHOR
 
   Nadim iibn Hamouda El Khemir
@@ -42,4 +55,17 @@ perl(1).
 
 =cut
 
-1 ;
\ No newline at end of file
+sub new
+{
+my ($class, %parameters) = @_;
+
+my $self = bless ({}, ref ($class) || $class);
+
+return ($self);
+}
+
+
+1 ; 
+
+__END__
+
